@@ -9,6 +9,8 @@
 BEGIN { $| = 1; print "1..1\n"; }
 END {print "not ok 1\n" unless $loaded;}
 use DBIx::DBSchema;
+use DBIx::DBSchema::DBD::Pg;
+use DBIx::DBSchema::DBD::mysql;
 $loaded = 1;
 print "ok 1\n";
 
